==> haskell-contravariant-1.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.5
id: contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
key: contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
license: BSD-3-Clause
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors.
category: Control, Data
abi: 745e81e7e3650c93ab38811415728ba3
exposed: True
exposed-modules:
    Data.Functor.Contravariant Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
import-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/contravariant-1.5
hs-libraries: HScontravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
depends:
    StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ base-4.11.1.0
    transformers-0.5.5.0
abi-depends: StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ=45bb6a3be5c8b9b97b4f8b0fdd8aa1dc
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.5.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.5.1
id: contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
key: contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
license: BSD-3-Clause
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors.
category: Control, Data
abi: 83bb1f7d9458cdd772cc62b51f405eb5
exposed: True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/contravariant-1.5.1
hs-libraries: HScontravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
depends:
    StateVar-1.1.1.1-2ewTKofpCGhC2np5dyFIaR base-4.12.0.0
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
